@@ -27,6 +27,9 @@ static const char *ready_icon_slideshow_text = "&readyicon";
 Gif_Stream *locked_slideshow;
 static const char *locked_slideshow_text = "&locked";
 
+Gif_Stream *bars_slideshow;
+static const char *bars_slideshow_text = 0;
+
 int nports;
 Port *ports;
 
@@ -49,7 +52,10 @@ struct timeval quota_allotment;
 int max_cheats;
 static int allow_cheats;
 
+int verbose;
+
 static int force_mono = 0;
+static int multiscreen = 0;
 
 
 static void
@@ -78,6 +84,7 @@ explicitly with `-OPTION'.\n\
 General options:\n\
   --display DISPLAY   Monitor the X display DISPLAY. You can monitor more than\n\
                       one display by giving this option multiple times.\n\
+  --multiscreen       Open every screen for each DISPLAY.\n\
   --help              Print this message and exit.\n\
   --version           Print version number and exit.\n\
 \n");
@@ -353,6 +360,8 @@ default_x_processing(XEvent *e)
        communication is asynchronous. */
     unschedule_data(A_IDLE_SELECT, (void *)port,
 		    (void *)e->xdestroywindow.window);
+    if (verbose)
+	fprintf(stderr, "Window 0x%x: destroyed\n", (unsigned)e->xdestroywindow.window);
     break;
     
    case MappingNotify:
@@ -423,15 +432,24 @@ optparse(char *arg, char *option, int unique, char *format, ...)
   va_start(val, format);
   
   /* Allow for long options. --[option] is equivalent to [option]. */
-  if (arg[0] == '-' && arg[1] == '-')
+  if (arg[0] == '-' && arg[1] == '-' && isalnum(arg[2]))
     arg += 2;
-  
+
   if (*format == 't') {
-    /* Toggle switch. -[option] means off; +[option] or [option] means on.
-       Arguments must be given with = syntax. */
-    if (*arg == '-') optparse_yesno = 0, arg++;
-    else if (*arg == '+') optparse_yesno = 1, arg++;
-    else optparse_yesno = 1;
+      /* Toggle switch. -[option] means off; +[option] or [option] means on.
+	 Arguments must be given with = syntax. */
+
+      /* Allow --no-WHATEVER as well as +WHATEVER. */
+      optparse_yesno = 1;
+      if (arg[0] == '-' && arg[1] == 'n' && arg[2] == 'o' && arg[3] == '-')
+	  arg++;
+      while (arg[0]== 'n' && arg[1] == 'o' && arg[2] == '-' && isalnum(arg[3]))
+	  optparse_yesno = !optparse_yesno, arg += 3;
+      
+      if (arg[0] == '-')
+	  optparse_yesno = 0, arg++;
+      else if (arg[0] == '+')
+	  optparse_yesno = 1, arg++;
     
   } else if (*format == 's') {
     /* Set option. -[option], +[option] and [option] are acceptable.
@@ -547,7 +565,10 @@ parse_options(int pargc, char **pargv)
       p->prev = o;
       o = p;
       
-    } else if (optparse(s, "breaktime", 1, "st", &o->break_time)) {
+    } else if (optparse(s, "bars-picture", 2, "ss", &bars_slideshow_text)
+	       || optparse(s, "bp", 2, "ss", &bars_slideshow_text))
+      ;
+    else if (optparse(s, "breaktime", 1, "st", &o->break_time)) {
       if (o->prev && !breaktime_warn_context) {
 	warning("meaning of `breaktime' following `after' has changed");
 	message("(You can specify `breaktime' multiple times, to lengthen a break");
@@ -617,6 +638,8 @@ parse_options(int pargc, char **pargv)
       check_mouse = optparse_yesno;
     else if (optparse(s, "multiply", 1, "tT", &o->multiply_delay))
       o->multiply = optparse_yesno;
+    else if (optparse(s, "multiscreen", 6, "t"))
+	multiscreen = optparse_yesno;
     else if (optparse(s, "maxhands", 2, "si", &o->max_hands))
       ;
     
@@ -648,11 +671,14 @@ parse_options(int pargc, char **pargv)
       ;
     else if (optparse(s, "top", 2, "t"))
       o->top = optparse_yesno;
-    
+
+    else if (optparse(s, "verbose", 4, "t")
+	     || optparse(s, "V", 1, "t"))
+	verbose = optparse_yesno;
     else if (optparse(s, "version", 1, "s")) {
       printf("LCDF Xwrits %s\n", VERSION);
       printf("\
-Copyright (C) 1994-2001 Eddie Kohler\n\
+Copyright (C) 1994-2002 Eddie Kohler\n\
 This is free software; see the source for copying conditions.\n\
 There is NO warranty, not even for merchantability or fitness for a\n\
 particular purpose.\n");
@@ -803,13 +829,14 @@ default_settings(void)
 #endif
 
 static void
-initialize_port(Port *port, Display *display, int screen_number)
+initialize_port(int portno, Display *display, int screen_number)
 {
   XVisualInfo visi_template;
   int nv, i;
   XVisualInfo *v;
   XVisualInfo *best_v = 0;
   VisualID default_visualid;
+  Port *port = &ports[portno];
   
   /* initialize Port fields */
   port->display = display;
@@ -818,6 +845,12 @@ initialize_port(Port *port, Display *display, int screen_number)
   port->root_window = RootWindow(display, screen_number);
   port->width = DisplayWidth(display, screen_number);
   port->height = DisplayHeight(display, screen_number);
+  port->port_number = portno;
+
+  /* set X socket */
+  FD_SET(port->x_socket, &x_socket_set);
+  if (port->x_socket > max_x_socket)
+      max_x_socket = port->x_socket;
   
   /* choose the Visual */
   default_visualid = DefaultVisual(display, screen_number)->visualid;
@@ -925,14 +958,95 @@ initialize_port(Port *port, Display *display, int screen_number)
 
 /* main! */
 
+typedef enum {
+    ST_NORMAL_WAIT, ST_FIRST_WARN, ST_WARN, ST_CANCEL_WAIT,
+    ST_REST, ST_LOCK, ST_AWAKE
+} XwritsState;
+
+void
+main_loop(void)
+{
+    XwritsState s = ST_NORMAL_WAIT;
+    int tran;
+    int was_lock = 0;
+
+    while (1) {
+	switch (s) {
+
+	  case ST_NORMAL_WAIT:
+	    ocurrent = &onormal;
+	    tran = wait_for_break(&normal_type_time);
+	    assert(tran == TRAN_WARN || tran == TRAN_REST);
+	    if (tran == TRAN_WARN)
+		s = ST_FIRST_WARN;
+	    break;
+
+	  case ST_FIRST_WARN:
+	    xwGETTIME(first_warn_time);
+	    was_lock = 0;
+	    s = ST_WARN;
+	    break;
+
+	  case ST_WARN:
+	    /* warn() will figure out current options by time */
+	    tran = warn(was_lock, &onormal);
+	    assert(tran == TRAN_CANCEL || tran == TRAN_REST || tran == TRAN_LOCK);
+	    if (tran == TRAN_REST)
+		s = ST_REST;
+	    else if (tran == TRAN_CANCEL)
+		s = ST_CANCEL_WAIT;
+	    else if (tran == TRAN_LOCK)
+		s = ST_LOCK;
+	    break;
+
+	  case ST_CANCEL_WAIT:
+	    tran = wait_for_break(&ocurrent->cancel_type_time);
+	    assert(tran == TRAN_WARN || tran == TRAN_REST);
+	    if (tran == TRAN_WARN)
+		s = ST_WARN;
+	    else
+		s = ST_NORMAL_WAIT;
+	    break;
+
+	  case ST_REST:
+	    was_lock = 0;
+	    tran = rest();
+	    assert(tran == TRAN_AWAKE || tran == TRAN_CANCEL || tran == TRAN_FAIL);
+	    if (tran == TRAN_AWAKE)
+		s = ST_AWAKE;
+	    else if (tran == TRAN_CANCEL)
+		s = ST_CANCEL_WAIT;
+	    else if (tran == TRAN_FAIL)
+		s = ST_WARN;
+	    break;
+
+	  case ST_LOCK:
+	    was_lock = 1;
+	    tran = lock();
+	    assert(tran == TRAN_AWAKE || tran == TRAN_FAIL);
+	    if (tran == TRAN_AWAKE)
+		s = ST_AWAKE;
+	    else if (tran == TRAN_FAIL)
+		s = ST_WARN;
+	    break;
+
+	  case ST_AWAKE:
+	    ready();
+	    unmap_all();
+	    s = ST_NORMAL_WAIT;
+	    break;
+	    
+	}
+    }
+}
+
 int
 main(int argc, char *argv[])
 {
   Options *o;
-  int i;
+  int i, j, orig_nports;
   int lock_possible = 0;
   struct timeval now;
-  struct timeval type_time;
   
   xwGETTIMEOFDAY(&genesis_time);
   init_scheduler();
@@ -983,28 +1097,41 @@ main(int argc, char *argv[])
   resting_icon_slideshow = parse_slideshow(resting_icon_slideshow_text, 1, force_mono);
   ready_slideshow = parse_slideshow(ready_slideshow_text, 1, force_mono);
   ready_icon_slideshow = parse_slideshow(ready_icon_slideshow_text, 1, force_mono);
-  locked_slideshow = parse_slideshow(locked_slideshow_text, 1, force_mono);
   ocurrent = &onormal;
 
   /* set up displays */
   FD_ZERO(&x_socket_set);
   max_x_socket = 0;
-  for (i = 0; i < nports; i++) {
+  orig_nports = nports;
+  for (i = 0; i < orig_nports; i++) {
     Display *display = XOpenDisplay(ports[i].display_name);
-    if (!display) error("can't open display `%s'", ports[i].display_name);
-    initialize_port(&ports[i], display, DefaultScreen(display));
-    ports[i].port_number = i;
-    FD_SET(ports[i].x_socket, &x_socket_set);
-    if (ports[i].x_socket > max_x_socket)
-      max_x_socket = ports[i].x_socket;
+    if (!display)
+	error("can't open display `%s'", ports[i].display_name);
+    if (!multiscreen)
+	initialize_port(i, display, DefaultScreen(display));
+    else
+	for (j = 0; j < ScreenCount(display); j++)
+	    if (j == 0)
+		initialize_port(i, display, j);
+	    else {
+		nports++;
+		ports = (Port *)xrealloc(ports, sizeof(Port) * nports);
+		ports[nports-1].display_name = ports[i].display_name;
+		initialize_port(nports-1, display, j);
+	    }
   }
 
   /* initialize pictures using first hand */
   if (lock_possible) {
-    Gif_Stream *bgfs = get_built_in_image(force_mono?"barsmono":"bars");
-    if (!bgfs && force_mono) bgfs = get_built_in_image("bars");
-    for (i = 0; i < nports; i++)
-      ports[i].bars_pixmap = Gif_XImage(ports[i].gfx, bgfs, 0);
+    locked_slideshow = parse_slideshow(locked_slideshow_text, 1, force_mono);
+    /* set bars_slideshow to default only if locked_slideshow is default */
+    if (!bars_slideshow_text)
+      bars_slideshow_text = (strcmp(locked_slideshow_text, "&locked") == 0 ? "&bars" : 0);
+    if (bars_slideshow_text) {
+      bars_slideshow = parse_slideshow(bars_slideshow_text, 1, force_mono);
+      for (i = 0; i < nports; i++)
+        ports[i].bars_pixmap = Gif_XImage(ports[i].gfx, bars_slideshow, 0);
+    }
   }
   
   /* watch keystrokes on all windows */
@@ -1021,43 +1148,7 @@ main(int argc, char *argv[])
   }
   
   /* main loop */
-  ocurrent = &onormal;		/* start with normal options */
-  type_time = normal_type_time;
-  
-  while (1) {
-    int tran, was_lock;
-    
-    /* wait for break */
-    tran = wait_for_break(&type_time);
-    if (tran == TRAN_REST) {
-      type_time = normal_type_time; /* reset to normal type time */
-      continue;
-    }
-    
-    /* warn */
-    xwGETTIME(first_warn_time);
-    tran = was_lock = 0;
-    while (tran != TRAN_AWAKE && tran != TRAN_CANCEL) {
-      /* warn() will figure out current options by time */
-      tran = warn(was_lock, &onormal);
-      if (tran == TRAN_REST) {
-	was_lock = 0;
-	tran = rest();
-      } else if (tran == TRAN_LOCK) {
-	was_lock = 1;
-	tran = lock();
-      }
-    }
-    
-    /* done with break? */
-    if (tran == TRAN_AWAKE) {
-      ready();
-      type_time = normal_type_time; /* reset to normal type time */
-    } else			/* tran == TRAN_CANCEL */
-      type_time = ocurrent->cancel_type_time;
-    
-    unmap_all();
-  }
+  main_loop();
   
   return 0;
 }
